@@ -30,6 +30,48 @@
  * Access rules should be inserted to the %GDATA_LINK_ACCESS_CONTROL_LIST URI of the feed or entry they should be applied to. This will return a
  * %GDATA_SERVICE_ERROR_CONFLICT error if a rule already exists on that feed or entry for that scope type and value.
  *
+ * <example>
+ * 	<title>Adding a Rule to the Access Control List for an Entry</title>
+ * 	<programlisting>
+ *	GDataService *service;
+ *	GDataEntry *entry;
+ *	GDataFeed *acl_feed;
+ *	GDataAccessRule *rule, *new_rule;
+ *	GError *error = NULL;
+ *
+ *	/<!-- -->* Retrieve a GDataEntry which will have a new rule inserted into its ACL. *<!-- -->/
+ *	service = build_my_service ();
+ *	entry = get_the_entry (service);
+ *
+ *	/<!-- -->* Create and insert a new access rule for example@gmail.com which grants them _no_ permissions on the entry.
+ *	 * In a real application, the GDataEntry subclass would define its own access roles which are more useful. For example,
+ *	 * GDataDocumentsEntry defines access roles for users who can read (but not write) a Google Document, and users who
+ *	 * can also write to the document. *<!-- -->/
+ *	rule = gdata_access_rule_new (NULL);
+ *	gdata_access_rule_set_role (rule, GDATA_ACCESS_ROLE_NONE); /<!-- -->* or, for example, GDATA_DOCUMENTS_ACCESS_ROLE_READER *<!-- -->/
+ *	gdata_access_rule_set_scope (rule, GDATA_ACCESS_SCOPE_USER, "example@gmail.com"); /<!-- -->* e-mail address of the user the ACL applies to *<!-- -->/
+ *
+ *	acl_link = gdata_entry_look_up_link (entry, GDATA_LINK_ACCESS_CONTROL_LIST);
+ *	new_rule = GDATA_ACCESS_RULE (gdata_service_insert_entry (GDATA_SERVICE (service), gdata_link_get_uri (acl_link), GDATA_ENTRY (rule),
+ *	                                                          NULL, &error));
+ *	g_object_unref (acl_link);
+ *
+ *	g_object_unref (rule);
+ *	g_object_unref (entry);
+ *	g_object_unref (service);
+ *
+ *	if (error != NULL) {
+ *		g_error ("Error inserting access rule: %s", error->message);
+ *		g_error_free (error);
+ *		return;
+ *	}
+ *
+ *	/<!-- -->* Potentially do something with the new_rule here, such as store its ID for later use. *<!-- -->/
+ *
+ *	g_object_unref (new_rule);
+ * 	</programlisting>
+ * </example>
+ *
  * Since: 0.3.0
  **/
 
@@ -122,6 +164,8 @@ gdata_access_rule_class_init (GDataAccessRuleClass *klass)
 	 * A value representing the user who is represented by the access rule, such as an
 	 * e-mail address for users, or a domain name for domains.
 	 *
+	 * This must be %NULL if and only if #GDataAccessRule:scope-type is %GDATA_ACCESS_SCOPE_DEFAULT.
+	 *
 	 * Since: 0.3.0
 	 **/
 	g_object_class_install_property (gobject_class, PROP_SCOPE_VALUE,
@@ -305,7 +349,9 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 
 			scope_value = xmlGetProp (node, (xmlChar*) "value");
 
-			if (xmlStrcmp (scope_type, (xmlChar*) GDATA_ACCESS_SCOPE_DEFAULT) == 0 && scope_value == NULL) {
+			/* The @value property is required for all scope types except "default".
+			 * See: https://developers.google.com/google-apps/calendar/v2/reference#gacl_reference */
+			if (xmlStrcmp (scope_type, (xmlChar*) GDATA_ACCESS_SCOPE_DEFAULT) != 0 && scope_value == NULL) {
 				xmlFree (scope_type);
 				return gdata_parser_error_required_property_missing (node, "value", error);
 			}
@@ -343,6 +389,10 @@ get_xml (GDataParsable *parsable, GString *xml_string)
 		} else {
 			gdata_parser_string_append_escaped (xml_string, "<gAcl:scope value='", priv->scope_value, "'/>");
 		}
+	} else {
+		/* gAcl:scope of type GDATA_ACCESS_SCOPE_DEFAULT. */
+		g_assert (priv->scope_type != NULL && strcmp (priv->scope_type, GDATA_ACCESS_SCOPE_DEFAULT) == 0);
+		g_string_append (xml_string, "<gAcl:scope type='default'/>");
 	}
 }
 
@@ -414,7 +464,7 @@ gdata_access_rule_get_role (GDataAccessRule *self)
  * gdata_access_rule_set_scope:
  * @self: a #GDataAccessRule
  * @type: a new scope type
- * @value: a new scope value, or %NULL
+ * @value: (allow-none): a new scope value, or %NULL
  *
  * Sets the #GDataAccessRule:scope-type property to @type and the #GDataAccessRule:scope-value property to @value.
  *
@@ -448,8 +498,8 @@ gdata_access_rule_set_scope (GDataAccessRule *self, const gchar *type, const gch
 /**
  * gdata_access_rule_get_scope:
  * @self: a #GDataAccessRule
- * @type: (out callee-allocates) (transfer none): return location for the scope type, or %NULL
- * @value: (out callee-allocates) (transfer none): return location for the scope value, or %NULL
+ * @type: (out callee-allocates) (transfer none) (allow-none): return location for the scope type, or %NULL
+ * @value: (out callee-allocates) (transfer none) (allow-none): return location for the scope value, or %NULL
  *
  * Gets the #GDataAccessRule:scope-type and #GDataAccessRule:scope-value properties.
  *
