@@ -36,6 +36,7 @@
 #include <glib/gi18n-lib.h>
 #include <string.h>
 #include <libxml/parser.h>
+#include <json-glib/json-glib.h>
 
 #include "gdata-parsable.h"
 #include "gdata-private.h"
@@ -51,10 +52,17 @@ static void gdata_parsable_get_property (GObject *object, guint property_id, GVa
 static void gdata_parsable_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec);
 static void gdata_parsable_finalize (GObject *object);
 static gboolean real_parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_data, GError **error);
+static gboolean real_parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GError **error);
+static const gchar *get_content_type (void);
 
 struct _GDataParsablePrivate {
+	/* XML stuff. */
 	GString *extra_xml;
 	GHashTable *extra_namespaces;
+
+	/* JSON stuff. */
+	GHashTable/*<gchar*, owned JsonNode*>*/ *extra_json;
+
 	gboolean constructed_from_xml;
 };
 
@@ -75,6 +83,8 @@ gdata_parsable_class_init (GDataParsableClass *klass)
 	gobject_class->set_property = gdata_parsable_set_property;
 	gobject_class->finalize = gdata_parsable_finalize;
 	klass->parse_xml = real_parse_xml;
+	klass->parse_json = real_parse_json;
+	klass->get_content_type = get_content_type;
 
 	/**
 	 * GDataParsable:constructed-from-xml:
@@ -98,6 +108,9 @@ gdata_parsable_init (GDataParsable *self)
 
 	self->priv->extra_xml = g_string_new ("");
 	self->priv->extra_namespaces = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+
+	self->priv->extra_json = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) json_node_free);
+
 	self->priv->constructed_from_xml = FALSE;
 }
 
@@ -142,6 +155,8 @@ gdata_parsable_finalize (GObject *object)
 	g_string_free (priv->extra_xml, TRUE);
 	g_hash_table_destroy (priv->extra_namespaces);
 
+	g_hash_table_destroy (priv->extra_json);
+
 	/* Chain up to the parent class */
 	G_OBJECT_CLASS (gdata_parsable_parent_class)->finalize (object);
 }
@@ -178,6 +193,95 @@ real_parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer us
 	return TRUE;
 }
 
+/* Extract the member node. This would be a lot easier if JsonReader had an API to return
+ * the current node (regardless of whether it's a value, object or array). FIXME: bgo#707100. */
+static JsonNode * /* transfer full */
+_json_reader_dup_current_node (JsonReader *reader)
+{
+	JsonNode *value;
+
+	if (json_reader_is_value (reader) == TRUE) {
+		/* Value nodes are easy. Well, ignoring the complication of nulls. */
+		if (json_reader_get_null_value (reader) == TRUE) {
+			value = json_node_new (JSON_NODE_NULL);
+		} else {
+			value = json_node_copy (json_reader_get_value (reader));
+		}
+	} else if (json_reader_is_object (reader) == TRUE) {
+		/* Object nodes require deep copies. */
+		gint i, members;
+		JsonObject *obj;
+
+		obj = json_object_new ();
+
+		for (i = 0, members = json_reader_count_members (reader); i < members; i++) {
+			json_reader_read_element (reader, i);
+			json_object_set_member (obj, json_reader_get_member_name (reader), _json_reader_dup_current_node (reader));
+			json_reader_end_element (reader);
+		}
+
+		value = json_node_new (JSON_NODE_OBJECT);
+		json_node_take_object (value, obj);
+	} else if (json_reader_is_array (reader) == TRUE) {
+		/* Array nodes require deep copies. */
+		gint i, elements;
+		JsonArray *arr;
+
+		arr = json_array_new ();
+
+		for (i = 0, elements = json_reader_count_elements (reader); i < elements; i++) {
+			json_reader_read_element (reader, i);
+			json_array_add_element (arr, _json_reader_dup_current_node (reader));
+			json_reader_end_element (reader);
+		}
+
+		value = json_node_new (JSON_NODE_ARRAY);
+		json_node_take_array (value, arr);
+	} else {
+		/* Uh-oh. */
+		g_assert_not_reached ();
+	}
+
+	return value;
+}
+
+static gboolean
+real_parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GError **error)
+{
+	gchar *json, *member_name;
+	JsonGenerator *generator;
+	JsonNode *value;
+
+	/* Unhandled JSON member. Save it and its value to ->extra_xml so that it's not lost if we
+	 * re-upload this Parsable to the server. */
+	member_name = g_strdup (json_reader_get_member_name (reader));
+	g_assert (member_name != NULL);
+
+	/* Extract a copy of the current node. */
+	value = _json_reader_dup_current_node (reader);
+	g_assert (value != NULL);
+
+	/* Serialise the value for debugging. */
+	generator = json_generator_new ();
+	json_generator_set_root (generator, value);
+
+	json = json_generator_to_data (generator, NULL);
+	g_debug ("Unhandled JSON member ‘%s’ in %s: %s", member_name, G_OBJECT_TYPE_NAME (parsable), json);
+	g_free (json);
+
+	g_object_unref (generator);
+
+	/* Save the value. Transfer ownership of the member_name and value. */
+	g_hash_table_replace (parsable->priv->extra_json, (gpointer) member_name, (gpointer) value);
+
+	return TRUE;
+}
+
+static const gchar *
+get_content_type (void) {
+	return "application/atom+xml";
+}
+
 /**
  * gdata_parsable_new_from_xml:
  * @parsable_type: the type of the class represented by the XML
@@ -320,6 +424,125 @@ _gdata_parsable_new_from_xml_node (GType parsable_type, xmlDoc *doc, xmlNode *no
 	return parsable;
 }
 
+/**
+ * gdata_parsable_new_from_json:
+ * @parsable_type: the type of the class represented by the JSON
+ * @json: the JSON for just the parsable object
+ * @length: the length of @json, or -1
+ * @error: a #GError, or %NULL
+ *
+ * Creates a new #GDataParsable subclass (of the given @parsable_type) from the given @json.
+ *
+ * An object of the given @parsable_type is created, and its <function>parse_json</function> and
+ * <function>post_parse_json</function> class functions called on the JSON node obtained from @json.
+ * <function>post_parse_json</function> is called once on the root node, while <function>parse_json</function> is called for
+ * each of the node's members.
+ *
+ * If @length is -1, @json will be assumed to be nul-terminated.
+ *
+ * If an error occurs during parsing, a suitable error from #GDataParserError will be returned.
+ *
+ * Return value: a new #GDataParsable, or %NULL; unref with g_object_unref()
+ *
+ * Since: 0.15.0
+ */
+GDataParsable *
+gdata_parsable_new_from_json (GType parsable_type, const gchar *json, gint length, GError **error)
+{
+	g_return_val_if_fail (g_type_is_a (parsable_type, GDATA_TYPE_PARSABLE), NULL);
+	g_return_val_if_fail (json != NULL && *json != '\0', NULL);
+	g_return_val_if_fail (length >= -1, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	return _gdata_parsable_new_from_json (parsable_type, json, length, NULL, error);
+}
+
+GDataParsable *
+_gdata_parsable_new_from_json (GType parsable_type, const gchar *json, gint length, gpointer user_data, GError **error)
+{
+	JsonParser *parser;
+	JsonReader *reader;
+	GDataParsable *parsable;
+	GError *child_error = NULL;
+
+	g_return_val_if_fail (g_type_is_a (parsable_type, GDATA_TYPE_PARSABLE), NULL);
+	g_return_val_if_fail (json != NULL && *json != '\0', NULL);
+	g_return_val_if_fail (length >= -1, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	if (length == -1)
+		length = strlen (json);
+
+	parser = json_parser_new ();
+	if (!json_parser_load_from_data (parser, json, length, &child_error)) {
+		g_set_error (error, GDATA_PARSER_ERROR, GDATA_PARSER_ERROR_PARSING_STRING,
+		             /* Translators: the parameter is an error message */
+		             _("Error parsing JSON: %s"), child_error->message);
+		g_error_free (child_error);
+		g_object_unref (parser);
+
+		return NULL;
+	}
+
+	reader = json_reader_new (json_parser_get_root (parser));
+	parsable = _gdata_parsable_new_from_json_node (parsable_type, reader, user_data, error);
+
+	g_object_unref (reader);
+	g_object_unref (parser);
+
+	return parsable;
+}
+
+GDataParsable *
+_gdata_parsable_new_from_json_node (GType parsable_type, JsonReader *reader, gpointer user_data, GError **error)
+{
+	GDataParsable *parsable;
+	GDataParsableClass *klass;
+	gint i;
+
+	g_return_val_if_fail (g_type_is_a (parsable_type, GDATA_TYPE_PARSABLE), NULL);
+	g_return_val_if_fail (reader != NULL, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	/* Indicator property which allows distinguishing between locally created and server based objects
+	 * as it is used for non-XML tasks, and adding another one for JSON would be a bit pointless. */
+	parsable = g_object_new (parsable_type, "constructed-from-xml", TRUE, NULL);
+
+	klass = GDATA_PARSABLE_GET_CLASS (parsable);
+	g_assert (klass->parse_json != NULL);
+
+	/* Check that the outermost node is an object. */
+	if (json_reader_is_object (reader) == FALSE) {
+		g_set_error (error, GDATA_PARSER_ERROR, GDATA_PARSER_ERROR_PARSING_STRING,
+		             /* Translators: the parameter is an error message */
+		             _("Error parsing JSON: %s"),
+		             _("Outermost JSON node is not an object."));
+		g_object_unref (parsable);
+		return NULL;
+	}
+
+	/* Parse each child member. This assumes the outermost node is an object. */
+	for (i = 0; i < json_reader_count_members (reader); i++) {
+		g_return_val_if_fail (json_reader_read_element (reader, i), NULL);
+
+		if (klass->parse_json (parsable, reader, user_data, error) == FALSE) {
+			g_object_unref (parsable);
+			return NULL;
+		}
+
+		json_reader_end_element (reader);
+	}
+
+	/* Call the post-parse function */
+	if (klass->post_parse_json != NULL &&
+	    klass->post_parse_json (parsable, user_data, error) == FALSE) {
+		g_object_unref (parsable);
+		return NULL;
+	}
+
+	return parsable;
+}
+
 static void
 build_namespaces_cb (gchar *prefix, gchar *href, GString *output)
 {
@@ -437,6 +660,82 @@ _gdata_parsable_get_xml (GDataParsable *self, GString *xml_string, gboolean decl
 		g_string_append_printf (xml_string, "</%s>", klass->element_name);
 }
 
+/**
+ * gdata_parsable_get_json:
+ * @self: a #GDataParsable
+ *
+ * Builds a JSON representation of the #GDataParsable in its current state, such that it could be inserted on the server. The JSON
+ * is valid for stand-alone use.
+ *
+ * Return value: the object's JSON; free with g_free()
+ *
+ * Since: 0.15.0
+ */
+gchar *
+gdata_parsable_get_json (GDataParsable *self)
+{
+	JsonGenerator *generator;
+	JsonBuilder *builder;
+	JsonNode *root;
+	gchar *output;
+
+	g_return_val_if_fail (GDATA_IS_PARSABLE (self), NULL);
+
+	/* Build the JSON tree. */
+	builder = json_builder_new ();
+	_gdata_parsable_get_json (self, builder);
+	root = json_builder_get_root (builder);
+	g_object_unref (builder);
+
+	/* Serialise it to a string. */
+	generator = json_generator_new ();
+	json_generator_set_root (generator, root);
+	output = json_generator_to_data (generator, NULL);
+	g_object_unref (generator);
+
+	json_node_free (root);
+
+	return output;
+}
+
+/*
+ * _gdata_parsable_get_json:
+ * @self: a #GDataParsable
+ * @builder: a #JsonBuilder to build the JSON in
+ *
+ * Builds a JSON representation of the #GDataParsable in its current state, such that it could be inserted on the server.
+ *
+ * Since: 0.15.0
+ */
+void
+_gdata_parsable_get_json (GDataParsable *self, JsonBuilder *builder)
+{
+	GDataParsableClass *klass;
+	GHashTableIter iter;
+	gchar *member_name;
+	JsonNode *value;
+
+	g_return_if_fail (GDATA_IS_PARSABLE (self));
+	g_return_if_fail (JSON_IS_BUILDER (builder));
+
+	klass = GDATA_PARSABLE_GET_CLASS (self);
+
+	json_builder_begin_object (builder);
+
+	/* Add the JSON. */
+	if (klass->get_json != NULL)
+		klass->get_json (self, builder);
+
+	/* Any extra JSON which we couldn't parse before? */
+	g_hash_table_iter_init (&iter, self->priv->extra_json);
+	while (g_hash_table_iter_next (&iter, (gpointer *) &member_name, (gpointer *) &value) == TRUE) {
+		json_builder_set_member_name (builder, member_name);
+		json_builder_add_value (builder, json_node_copy (value)); /* transfers ownership */
+	}
+
+	json_builder_end_object (builder);
+}
+
 /*
  * _gdata_parsable_is_constructed_from_xml:
  * @self: a #GDataParsable
