@@ -77,10 +77,14 @@ static GDataFeed *__gdata_service_query (GDataService *self, GDataAuthorizationD
                                          GType entry_type, GCancellable *cancellable, GDataQueryProgressCallback progress_callback,
                                          gpointer progress_user_data, GError **error, gboolean is_async);
 
+static SoupURI *_get_proxy_uri (GDataService *self);
+static void _set_proxy_uri (GDataService *self, SoupURI *proxy_uri);
+
 struct _GDataServicePrivate {
 	SoupSession *session;
 	gchar *locale;
 	GDataAuthorizer *authorizer;
+	GProxyResolver *proxy_resolver;
 };
 
 enum {
@@ -88,6 +92,7 @@ enum {
 	PROP_TIMEOUT,
 	PROP_LOCALE,
 	PROP_AUTHORIZER,
+	PROP_PROXY_RESOLVER,
 };
 
 G_DEFINE_TYPE (GDataService, gdata_service, G_TYPE_OBJECT)
@@ -118,6 +123,7 @@ gdata_service_class_init (GDataServiceClass *klass)
 	 * Note that if a #GDataAuthorizer is being used with this #GDataService, the authorizer might also need its proxy URI setting.
 	 *
 	 * Since: 0.2.0
+	 * Deprecated: Use #GDataService:proxy-resolver instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
 	 **/
 	g_object_class_install_property (gobject_class, PROP_PROXY_URI,
 	                                 g_param_spec_boxed ("proxy-uri",
@@ -185,6 +191,19 @@ gdata_service_class_init (GDataServiceClass *klass)
 	                                                      "Authorizer", "An authorizer object to provide an authorization token for each request.",
 	                                                      GDATA_TYPE_AUTHORIZER,
 	                                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+
+	/**
+	 * GDataService:proxy-resolver:
+	 *
+	 * The #GProxyResolver used to determine a proxy URI.  Setting this will clear the #GDataService:proxy-uri property.
+	 *
+	 * Since: 0.15.0
+	 */
+	g_object_class_install_property (gobject_class, PROP_PROXY_RESOLVER,
+	                                 g_param_spec_object ("proxy-resolver",
+	                                                      "Proxy Resolver", "A GProxyResolver used to determine a proxy URI.",
+	                                                      G_TYPE_PROXY_RESOLVER,
+	                                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -199,6 +218,9 @@ gdata_service_init (GDataService *self)
 	/* Proxy the SoupSession's proxy-uri and timeout properties */
 	g_signal_connect (self->priv->session, "notify::proxy-uri", (GCallback) notify_proxy_uri_cb, self);
 	g_signal_connect (self->priv->session, "notify::timeout", (GCallback) notify_timeout_cb, self);
+
+	/* Keep our GProxyResolver synchronized with SoupSession's. */
+	g_object_bind_property (self->priv->session, "proxy-resolver", self, "proxy-resolver", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
 }
 
 static void
@@ -214,6 +236,8 @@ gdata_service_dispose (GObject *object)
 		g_object_unref (priv->session);
 	priv->session = NULL;
 
+	g_clear_object (&priv->proxy_resolver);
+
 	/* Chain up to the parent class */
 	G_OBJECT_CLASS (gdata_service_parent_class)->dispose (object);
 }
@@ -236,7 +260,7 @@ gdata_service_get_property (GObject *object, guint property_id, GValue *value, G
 
 	switch (property_id) {
 		case PROP_PROXY_URI:
-			g_value_set_boxed (value, gdata_service_get_proxy_uri (GDATA_SERVICE (object)));
+			g_value_set_boxed (value, _get_proxy_uri (GDATA_SERVICE (object)));
 			break;
 		case PROP_TIMEOUT:
 			g_value_set_uint (value, gdata_service_get_timeout (GDATA_SERVICE (object)));
@@ -247,6 +271,9 @@ gdata_service_get_property (GObject *object, guint property_id, GValue *value, G
 		case PROP_AUTHORIZER:
 			g_value_set_object (value, priv->authorizer);
 			break;
+		case PROP_PROXY_RESOLVER:
+			g_value_set_object (value, priv->proxy_resolver);
+			break;
 		default:
 			/* We don't have any other property... */
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -259,7 +286,7 @@ gdata_service_set_property (GObject *object, guint property_id, const GValue *va
 {
 	switch (property_id) {
 		case PROP_PROXY_URI:
-			gdata_service_set_proxy_uri (GDATA_SERVICE (object), g_value_get_boxed (value));
+			_set_proxy_uri (GDATA_SERVICE (object), g_value_get_boxed (value));
 			break;
 		case PROP_TIMEOUT:
 			gdata_service_set_timeout (GDATA_SERVICE (object), g_value_get_uint (value));
@@ -270,6 +297,9 @@ gdata_service_set_property (GObject *object, guint property_id, const GValue *va
 		case PROP_AUTHORIZER:
 			gdata_service_set_authorizer (GDATA_SERVICE (object), g_value_get_object (value));
 			break;
+		case PROP_PROXY_RESOLVER:
+			gdata_service_set_proxy_resolver (GDATA_SERVICE (object), g_value_get_object (value));
+			break;
 		default:
 			/* We don't have any other property... */
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -913,8 +943,10 @@ __gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, con
                        gboolean is_async)
 {
 	GDataServiceClass *klass;
-	GDataFeed *feed;
+	GDataFeed *feed = NULL;
 	SoupMessage *message;
+	SoupMessageHeaders *headers;
+	const gchar *content_type;
 
 	message = _gdata_service_query (self, domain, feed_uri, query, cancellable, error);
 	if (message == NULL)
@@ -922,8 +954,23 @@ __gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, con
 
 	g_assert (message->response_body->data != NULL);
 	klass = GDATA_SERVICE_GET_CLASS (self);
-	feed = _gdata_feed_new_from_xml (klass->feed_type, message->response_body->data, message->response_body->length, entry_type,
-	                                 progress_callback, progress_user_data, is_async, error);
+
+	headers = message->response_headers;
+	content_type = soup_message_headers_get_content_type (headers, NULL);
+
+	if (content_type != NULL && strcmp (content_type, "application/json") == 0) {
+		/* Definitely JSON. */
+		g_debug("JSON content type detected.");
+		feed = _gdata_feed_new_from_json (klass->feed_type, message->response_body->data, message->response_body->length, entry_type,
+		                                  progress_callback, progress_user_data, is_async, error);
+	} else {
+		/* Potentially XML. Don't bother checking the Content-Type, since the parser
+		 * will fail gracefully if the response body is not valid XML. */
+		g_debug("XML content type detected.");
+		feed = _gdata_feed_new_from_xml (klass->feed_type, message->response_body->data, message->response_body->length, entry_type,
+		                                 progress_callback, progress_user_data, is_async, error);
+	}
+
 	g_object_unref (message);
 
 	if (feed == NULL)
@@ -1332,6 +1379,7 @@ gdata_service_insert_entry (GDataService *self, GDataAuthorizationDomain *domain
 	SoupMessage *message;
 	gchar *upload_data;
 	guint status;
+	GDataParsableClass *klass;
 
 	g_return_val_if_fail (GDATA_IS_SERVICE (self), NULL);
 	g_return_val_if_fail (domain == NULL || GDATA_IS_AUTHORIZATION_DOMAIN (domain), NULL);
@@ -1349,8 +1397,15 @@ gdata_service_insert_entry (GDataService *self, GDataAuthorizationDomain *domain
 	message = _gdata_service_build_message (self, domain, SOUP_METHOD_POST, upload_uri, NULL, FALSE);
 
 	/* Append the data */
-	upload_data = gdata_parsable_get_xml (GDATA_PARSABLE (entry));
-	soup_message_set_request (message, "application/atom+xml", SOUP_MEMORY_TAKE, upload_data, strlen (upload_data));
+	klass = GDATA_PARSABLE_GET_CLASS (entry);
+	g_assert (klass->get_content_type != NULL);
+	if (g_strcmp0 (klass->get_content_type (), "application/json") == 0) {
+		upload_data = gdata_parsable_get_json (GDATA_PARSABLE (entry));
+		soup_message_set_request (message, "application/json", SOUP_MEMORY_TAKE, upload_data, strlen (upload_data));
+	} else {
+		upload_data = gdata_parsable_get_xml (GDATA_PARSABLE (entry));
+		soup_message_set_request (message, "application/atom+xml", SOUP_MEMORY_TAKE, upload_data, strlen (upload_data));
+	}
 
 	/* Send the message */
 	status = _gdata_service_send_message (self, message, cancellable, error);
@@ -1359,20 +1414,25 @@ gdata_service_insert_entry (GDataService *self, GDataAuthorizationDomain *domain
 		/* Redirect error or cancelled */
 		g_object_unref (message);
 		return NULL;
-	} else if (status != SOUP_STATUS_CREATED) {
-		/* Error */
-		GDataServiceClass *klass = GDATA_SERVICE_GET_CLASS (self);
-		g_assert (klass->parse_error_response != NULL);
-		klass->parse_error_response (self, GDATA_OPERATION_INSERTION, status, message->reason_phrase, message->response_body->data,
-		                             message->response_body->length, error);
+	} else if (status != SOUP_STATUS_CREATED && status != SOUP_STATUS_OK) {
+		/* Error: for XML APIs Google returns CREATED and for JSON it returns OK. */
+		GDataServiceClass *service_klass = GDATA_SERVICE_GET_CLASS (self);
+		g_assert (service_klass->parse_error_response != NULL);
+		service_klass->parse_error_response (self, GDATA_OPERATION_INSERTION, status, message->reason_phrase, message->response_body->data,
+		                                     message->response_body->length, error);
 		g_object_unref (message);
 		return NULL;
 	}
 
-	/* Parse the XML; create and return a new GDataEntry of the same type as @entry */
+	/* Parse the XML or JSON according to GDataEntry type; create and return a new GDataEntry of the same type as @entry */
 	g_assert (message->response_body->data != NULL);
-	updated_entry = GDATA_ENTRY (gdata_parsable_new_from_xml (G_OBJECT_TYPE (entry), message->response_body->data, message->response_body->length,
-	                                                          error));
+	if (g_strcmp0 (klass->get_content_type (), "application/json") == 0) {
+		updated_entry = GDATA_ENTRY (gdata_parsable_new_from_json (G_OBJECT_TYPE (entry), message->response_body->data,
+		                             message->response_body->length, error));
+	} else {
+		updated_entry = GDATA_ENTRY (gdata_parsable_new_from_xml (G_OBJECT_TYPE (entry), message->response_body->data,
+		                             message->response_body->length, error));
+	}
 	g_object_unref (message);
 
 	return updated_entry;
@@ -1523,6 +1583,7 @@ gdata_service_update_entry (GDataService *self, GDataAuthorizationDomain *domain
 	SoupMessage *message;
 	gchar *upload_data;
 	guint status;
+	GDataParsableClass *klass;
 
 	g_return_val_if_fail (GDATA_IS_SERVICE (self), NULL);
 	g_return_val_if_fail (domain == NULL || GDATA_IS_AUTHORIZATION_DOMAIN (domain), NULL);
@@ -1530,14 +1591,24 @@ gdata_service_update_entry (GDataService *self, GDataAuthorizationDomain *domain
 	g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	/* Get the edit URI */
-	_link = gdata_entry_look_up_link (entry, GDATA_LINK_EDIT);
-	g_assert (_link != NULL);
-	message = _gdata_service_build_message (self, domain, SOUP_METHOD_PUT, gdata_link_get_uri (_link), gdata_entry_get_etag (entry), TRUE);
-
 	/* Append the data */
-	upload_data = gdata_parsable_get_xml (GDATA_PARSABLE (entry));
-	soup_message_set_request (message, "application/atom+xml", SOUP_MEMORY_TAKE, upload_data, strlen (upload_data));
+	klass = GDATA_PARSABLE_GET_CLASS (entry);
+	g_assert (klass->get_content_type != NULL);
+	if (g_strcmp0 (klass->get_content_type (), "application/json") == 0) {
+		/* Get the edit URI */
+		_link = gdata_entry_look_up_link (entry, GDATA_LINK_SELF);
+		g_assert (_link != NULL);
+		message = _gdata_service_build_message (self, domain, SOUP_METHOD_PUT, gdata_link_get_uri (_link), gdata_entry_get_etag (entry), TRUE);
+		upload_data = gdata_parsable_get_json (GDATA_PARSABLE (entry));
+		soup_message_set_request (message, "application/json", SOUP_MEMORY_TAKE, upload_data, strlen (upload_data));
+	} else {
+		/* Get the edit URI */
+		_link = gdata_entry_look_up_link (entry, GDATA_LINK_EDIT);
+		g_assert (_link != NULL);
+		message = _gdata_service_build_message (self, domain, SOUP_METHOD_PUT, gdata_link_get_uri (_link), gdata_entry_get_etag (entry), TRUE);
+		upload_data = gdata_parsable_get_xml (GDATA_PARSABLE (entry));
+		soup_message_set_request (message, "application/atom+xml", SOUP_MEMORY_TAKE, upload_data, strlen (upload_data));
+	}
 
 	/* Send the message */
 	status = _gdata_service_send_message (self, message, cancellable, error);
@@ -1548,18 +1619,22 @@ gdata_service_update_entry (GDataService *self, GDataAuthorizationDomain *domain
 		return NULL;
 	} else if (status != SOUP_STATUS_OK) {
 		/* Error */
-		GDataServiceClass *klass = GDATA_SERVICE_GET_CLASS (self);
-		g_assert (klass->parse_error_response != NULL);
-		klass->parse_error_response (self, GDATA_OPERATION_UPDATE, status, message->reason_phrase, message->response_body->data,
-		                             message->response_body->length, error);
+		GDataServiceClass *service_klass = GDATA_SERVICE_GET_CLASS (self);
+		g_assert (service_klass->parse_error_response != NULL);
+		service_klass->parse_error_response (self, GDATA_OPERATION_UPDATE, status, message->reason_phrase, message->response_body->data,
+		                                     message->response_body->length, error);
 		g_object_unref (message);
 		return NULL;
 	}
 
 	/* Parse the XML; create and return a new GDataEntry of the same type as @entry */
-	g_assert (message->response_body->data != NULL);
-	updated_entry = GDATA_ENTRY (gdata_parsable_new_from_xml (G_OBJECT_TYPE (entry), message->response_body->data, message->response_body->length,
-	                                                          error));
+	if (g_strcmp0 (klass->get_content_type (), "application/json") == 0) {
+		updated_entry = GDATA_ENTRY (gdata_parsable_new_from_json (G_OBJECT_TYPE (entry), message->response_body->data,
+		                         message->response_body->length, error));
+	} else {
+		updated_entry = GDATA_ENTRY (gdata_parsable_new_from_xml (G_OBJECT_TYPE (entry), message->response_body->data,
+		                             message->response_body->length, error));
+	}
 	g_object_unref (message);
 
 	return updated_entry;
@@ -1703,6 +1778,7 @@ gdata_service_delete_entry (GDataService *self, GDataAuthorizationDomain *domain
 	SoupMessage *message;
 	guint status;
 	gchar *fixed_uri;
+	GDataParsableClass *klass;
 
 	g_return_val_if_fail (GDATA_IS_SERVICE (self), FALSE);
 	g_return_val_if_fail (domain == NULL || GDATA_IS_AUTHORIZATION_DOMAIN (domain), FALSE);
@@ -1711,7 +1787,13 @@ gdata_service_delete_entry (GDataService *self, GDataAuthorizationDomain *domain
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
 	/* Get the edit URI. We have to fix it to always use HTTPS as YouTube videos appear to incorrectly return a HTTP URI as their edit URI. */
-	_link = gdata_entry_look_up_link (entry, GDATA_LINK_EDIT);
+	klass = GDATA_PARSABLE_GET_CLASS (entry);
+	g_assert (klass->get_content_type != NULL);
+	if (g_strcmp0 (klass->get_content_type (), "application/json") == 0) {
+		_link = gdata_entry_look_up_link (entry, GDATA_LINK_SELF);
+	} else {
+		_link = gdata_entry_look_up_link (entry, GDATA_LINK_EDIT);
+	}
 	g_assert (_link != NULL);
 
 	fixed_uri = _gdata_service_fix_uri_scheme (gdata_link_get_uri (_link));
@@ -1727,10 +1809,10 @@ gdata_service_delete_entry (GDataService *self, GDataAuthorizationDomain *domain
 		return FALSE;
 	} else if (status != SOUP_STATUS_OK) {
 		/* Error */
-		GDataServiceClass *klass = GDATA_SERVICE_GET_CLASS (self);
-		g_assert (klass->parse_error_response != NULL);
-		klass->parse_error_response (self, GDATA_OPERATION_DELETION, status, message->reason_phrase, message->response_body->data,
-		                             message->response_body->length, error);
+		GDataServiceClass *service_klass = GDATA_SERVICE_GET_CLASS (self);
+		g_assert (service_klass->parse_error_response != NULL);
+		service_klass->parse_error_response (self, GDATA_OPERATION_DELETION, status, message->reason_phrase, message->response_body->data,
+		                                     message->response_body->length, error);
 		g_object_unref (message);
 		return FALSE;
 	}
@@ -1746,18 +1828,9 @@ notify_proxy_uri_cb (GObject *gobject, GParamSpec *pspec, GObject *self)
 	g_object_notify (self, "proxy-uri");
 }
 
-/**
- * gdata_service_get_proxy_uri:
- * @self: a #GDataService
- *
- * Gets the proxy URI on the #GDataService's #SoupSession.
- *
- * Return value: (transfer none): the proxy URI, or %NULL
- *
- * Since: 0.2.0
- **/
-SoupURI *
-gdata_service_get_proxy_uri (GDataService *self)
+/* Static function which isn't deprecated so we can continue using it internally. */
+static SoupURI *
+_get_proxy_uri (GDataService *self)
 {
 	SoupURI *proxy_uri;
 
@@ -1769,6 +1842,32 @@ gdata_service_get_proxy_uri (GDataService *self)
 	return proxy_uri;
 }
 
+/**
+ * gdata_service_get_proxy_uri:
+ * @self: a #GDataService
+ *
+ * Gets the proxy URI on the #GDataService's #SoupSession.
+ *
+ * Return value: (transfer none): the proxy URI, or %NULL
+ *
+ * Since: 0.2.0
+ * Deprecated: Use gdata_service_get_proxy_resolver() instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
+ **/
+SoupURI *
+gdata_service_get_proxy_uri (GDataService *self)
+{
+	return _get_proxy_uri (self);
+}
+
+/* Static function which isn't deprecated so we can continue using it internally. */
+static void
+_set_proxy_uri (GDataService *self, SoupURI *proxy_uri)
+{
+	g_return_if_fail (GDATA_IS_SERVICE (self));
+	g_object_set (self->priv->session, SOUP_SESSION_PROXY_URI, proxy_uri, NULL);
+	g_object_notify (G_OBJECT (self), "proxy-uri");
+}
+
 /**
  * gdata_service_set_proxy_uri:
  * @self: a #GDataService
@@ -1782,13 +1881,57 @@ gdata_service_get_proxy_uri (GDataService *self)
  * Note that if a #GDataAuthorizer is being used with this #GDataService, the authorizer might also need its proxy URI setting.
  *
  * Since: 0.2.0
+ * Deprecated: Use gdata_service_set_proxy_resolver() instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
  **/
 void
 gdata_service_set_proxy_uri (GDataService *self, SoupURI *proxy_uri)
+{
+	_set_proxy_uri (self, proxy_uri);
+}
+
+/**
+ * gdata_service_get_proxy_resolver:
+ * @self: a #GDataService
+ *
+ * Gets the #GProxyResolver on the #GDataService's #SoupSession.
+ *
+ * Return value: (transfer none) (allow-none): a #GProxyResolver, or %NULL
+ *
+ * Since: 0.15.0
+ */
+GProxyResolver *
+gdata_service_get_proxy_resolver (GDataService *self)
+{
+	g_return_val_if_fail (GDATA_IS_SERVICE (self), NULL);
+
+	return self->priv->proxy_resolver;
+}
+
+/**
+ * gdata_service_set_proxy_resolver:
+ * @self: a #GDataService
+ * @proxy_resolver: (allow-none): a #GProxyResolver, or %NULL
+ *
+ * Sets the #GProxyResolver on the #SoupSession used internally by the given #GDataService.
+ *
+ * Setting this will clear the #GDataService:proxy-uri property.
+ *
+ * Since: 0.15.0
+ */
+void
+gdata_service_set_proxy_resolver (GDataService *self, GProxyResolver *proxy_resolver)
 {
 	g_return_if_fail (GDATA_IS_SERVICE (self));
-	g_object_set (self->priv->session, SOUP_SESSION_PROXY_URI, proxy_uri, NULL);
-	g_object_notify (G_OBJECT (self), "proxy-uri");
+	g_return_if_fail (proxy_resolver == NULL || G_IS_PROXY_RESOLVER (proxy_resolver));
+
+	if (proxy_resolver != NULL) {
+		g_object_ref (proxy_resolver);
+	}
+
+	g_clear_object (&self->priv->proxy_resolver);
+	self->priv->proxy_resolver = proxy_resolver;
+
+	g_object_notify (G_OBJECT (self), "proxy-resolver");
 }
 
 static void
