@@ -25,7 +25,6 @@
 #include <libxml/xmlsave.h>
 
 #include "common.h"
-#include "mock-server.h"
 
 /* %TRUE if interactive tests should be skipped because we're running automatically (for example) */
 static gboolean no_interactive = FALSE;
@@ -49,11 +48,13 @@ static gboolean write_traces = FALSE;
 static gboolean compare_traces = FALSE;
 
 /* Global mock server instance used by all tests. */
-static GDataMockServer *mock_server = NULL;
+static UhmServer *mock_server = NULL;
 
 void
 gdata_test_init (int argc, char **argv)
 {
+	GTlsCertificate *cert;
+	GError *child_error = NULL;
 	gint i;
 
 #if !GLIB_CHECK_VERSION (2, 35, 0)
@@ -126,21 +127,28 @@ gdata_test_init (int argc, char **argv)
 	g_setenv ("G_MESSAGES_DEBUG", "libgdata", FALSE);
 	g_setenv ("LIBGDATA_LAX_SSL_CERTIFICATES", "1", FALSE);
 
-	mock_server = gdata_mock_server_new ();
-	gdata_mock_server_set_enable_logging (mock_server, write_traces);
-	gdata_mock_server_set_enable_online (mock_server, write_traces || compare_traces);
+	mock_server = uhm_server_new ();
+	uhm_server_set_enable_logging (mock_server, write_traces);
+	uhm_server_set_enable_online (mock_server, write_traces || compare_traces);
+
+	/* Build the certificate. */
+	cert = g_tls_certificate_new_from_files (TEST_FILE_DIR "cert.pem", TEST_FILE_DIR "key.pem", &child_error);
+	g_assert_no_error (child_error);
+	/* Set it as the property. */
+	uhm_server_set_tls_certificate (mock_server, cert);
+	g_object_unref (cert);
 }
 
 /*
  * gdata_test_get_mock_server:
  *
- * Returns the singleton #GDataMockServer instance used throughout the test suite.
+ * Returns the singleton #UhmServer instance used throughout the test suite.
  *
  * Return value: (transfer none): the mock server
  *
  * Since: 0.13.4
  */
-GDataMockServer *
+UhmServer *
 gdata_test_get_mock_server (void)
 {
 	return mock_server;
@@ -630,6 +638,167 @@ gdata_test_compare_xml (GDataParsable *parsable, const gchar *expected_xml, gboo
 	return success;
 }
 
+static gboolean
+compare_json_nodes (JsonNode *node1, JsonNode *node2)
+{
+	if (node1 == node2)
+		return TRUE;
+
+	if (JSON_NODE_TYPE (node1) != JSON_NODE_TYPE (node2))
+		return FALSE;
+
+	switch (JSON_NODE_TYPE (node1)) {
+		case JSON_NODE_OBJECT: {
+			JsonObject *object1, *object2;
+			guint size1, size2;
+			GList *members, *i;
+
+			object1 = json_node_get_object (node1);
+			object2 = json_node_get_object (node2);
+
+			size1 = json_object_get_size (object1);
+			size2 = json_object_get_size (object2);
+
+			if (size1 != size2)
+				return FALSE;
+
+			/* Iterate over the first object, checking that every member is also present in the second object. */
+			members = json_object_get_members (object1);
+
+			for (i = members; i != NULL; i = i->next) {
+				JsonNode *child_node1, *child_node2;
+
+				child_node1 = json_object_get_member (object1, i->data);
+				child_node2 = json_object_get_member (object2, i->data);
+
+				g_assert (child_node1 != NULL);
+				if (child_node2 == NULL) {
+					g_list_free (members);
+					return FALSE;
+				}
+
+				if (compare_json_nodes (child_node1, child_node2) == FALSE) {
+					g_list_free (members);
+					return FALSE;
+				}
+			}
+
+			g_list_free (members);
+
+			return TRUE;
+		}
+		case JSON_NODE_ARRAY: {
+			JsonArray *array1, *array2;
+			guint length1, length2, i;
+
+			array1 = json_node_get_array (node1);
+			array2 = json_node_get_array (node2);
+
+			length1 = json_array_get_length (array1);
+			length2 = json_array_get_length (array2);
+
+			if (length1 != length2)
+				return FALSE;
+
+			/* Iterate over both arrays, checking the elements at each index are identical. */
+			for (i = 0; i < length1; i++) {
+				JsonNode *child_node1, *child_node2;
+
+				child_node1 = json_array_get_element (array1, i);
+				child_node2 = json_array_get_element (array2, i);
+
+				if (compare_json_nodes (child_node1, child_node2) == FALSE)
+					return FALSE;
+			}
+
+			return TRUE;
+		}
+		case JSON_NODE_VALUE: {
+			GType type1, type2;
+
+			type1 = json_node_get_value_type (node1);
+			type2 = json_node_get_value_type (node2);
+
+			if (type1 != type2)
+				return FALSE;
+
+			switch (type1) {
+				case G_TYPE_BOOLEAN:
+					return (json_node_get_boolean (node1) == json_node_get_boolean (node2)) ? TRUE : FALSE;
+				case G_TYPE_DOUBLE:
+					/* Note: This doesn't need an epsilon-based comparison because we only want to return
+					 * true if the string representation of the two values is equal — and if it is, their
+					 * parsed values should be binary identical too. */
+					return (json_node_get_double (node1) == json_node_get_double (node2)) ? TRUE : FALSE;
+				case G_TYPE_INT64:
+					return (json_node_get_int (node1) == json_node_get_int (node2)) ? TRUE : FALSE;
+				case G_TYPE_STRING:
+					return (g_strcmp0 (json_node_get_string (node1), json_node_get_string (node2)) == 0) ? TRUE : FALSE;
+				default:
+					/* JSON doesn't support any other types. */
+					g_assert_not_reached ();
+			}
+
+			return TRUE;
+		}
+		case JSON_NODE_NULL:
+			return TRUE;
+		default:
+			g_assert_not_reached ();
+	}
+}
+
+gboolean
+gdata_test_compare_json_strings (const gchar *parsable_json, const gchar *expected_json, gboolean print_error)
+{
+	gboolean success;
+	JsonParser *parsable_parser, *expected_parser;
+	GError *child_error = NULL;
+
+	/* Parse both strings. */
+	parsable_parser = json_parser_new ();
+	expected_parser = json_parser_new ();
+
+	json_parser_load_from_data (parsable_parser, parsable_json, -1, &child_error);
+	if (child_error != NULL) {
+		if (print_error == TRUE) {
+			g_message ("\n\nParsable: %s\n\nNot valid JSON: %s", parsable_json, child_error->message);
+		}
+
+		g_error_free (child_error);
+		return FALSE;
+	}
+
+	json_parser_load_from_data (expected_parser, expected_json, -1, &child_error);
+	g_assert_no_error (child_error); /* this really should never fail; or the test has encoded bad JSON */
+
+	/* Recursively compare the two JSON nodes. */
+	success = compare_json_nodes (json_parser_get_root (parsable_parser), json_parser_get_root (expected_parser));
+	if (success == FALSE && print_error == TRUE) {
+		/* The comparison has failed, so print out the two JSON strings for ease of debugging */
+		g_message ("\n\nParsable: %s\n\nExpected: %s\n\n", parsable_json, expected_json);
+	}
+
+	g_object_unref (expected_parser);
+	g_object_unref (parsable_parser);
+
+	return success;
+}
+
+gboolean
+gdata_test_compare_json (GDataParsable *parsable, const gchar *expected_json, gboolean print_error)
+{
+	gboolean success;
+	gchar *parsable_json;
+
+	/* Get a JSON string for the GDataParsable. */
+	parsable_json = gdata_parsable_get_json (parsable);
+	success = gdata_test_compare_json_strings (parsable_json, expected_json, print_error);
+	g_free (parsable_json);
+
+	return success;
+}
+
 gboolean
 gdata_test_compare_kind (GDataEntry *entry, const gchar *expected_term, const gchar *expected_label)
 {
@@ -750,7 +919,7 @@ gdata_test_debug_handler (const gchar *log_domain, GLogLevelFlags log_level, con
 
 	/* Log to the trace file. */
 	if (message != NULL && (*message == '<' || *message == '>' || *message == ' ') && *(message + 1) == ' ') {
-		gdata_mock_server_received_message_chunk (mock_server, message, strlen (message));
+		uhm_server_received_message_chunk (mock_server, message, strlen (message), NULL);
 	}
 }
 
@@ -763,7 +932,7 @@ gdata_test_assert_handler (const gchar *message)
 
 /**
  * gdata_test_set_https_port:
- * @server: a #GDataMockServer
+ * @server: a #UhmServer
  *
  * Sets the HTTPS port used for all future libgdata requests to that used by the given mock @server,
  * effectively redirecting all client requests to the mock server.
@@ -771,44 +940,44 @@ gdata_test_assert_handler (const gchar *message)
  * Since: 0.13.4
  */
 void
-gdata_test_set_https_port (GDataMockServer *server)
+gdata_test_set_https_port (UhmServer *server)
 {
-	gchar *port_string = g_strdup_printf ("%u", gdata_mock_server_get_port (server));
+	gchar *port_string = g_strdup_printf ("%u", uhm_server_get_port (server));
 	g_setenv ("LIBGDATA_HTTPS_PORT", port_string, TRUE);
 	g_free (port_string);
 }
 
 /**
  * gdata_test_mock_server_start_trace:
- * @server: a #GDataMockServer
+ * @server: a #UhmServer
  * @trace_filename: filename of the trace to load
  *
- * Wrapper around gdata_mock_server_start_trace() which additionally sets the <code class="literal">LIBGDATA_HTTPS_PORT</code>
+ * Wrapper around uhm_server_start_trace() which additionally sets the <code class="literal">LIBGDATA_HTTPS_PORT</code>
  * environment variable to redirect all libgdata requests to the mock server.
  *
  * Since: 0.13.4
  */
 void
-gdata_test_mock_server_start_trace (GDataMockServer *server, const gchar *trace_filename)
+gdata_test_mock_server_start_trace (UhmServer *server, const gchar *trace_filename)
 {
-	gdata_mock_server_start_trace (server, trace_filename);
+	uhm_server_start_trace (server, trace_filename, NULL);
 	gdata_test_set_https_port (server);
 }
 
 /**
  * gdata_test_mock_server_handle_message_error:
- * @server: a #GDataMockServer
+ * @server: a #UhmServer
  * @message: the message whose response should be filled
  * @client: the currently connected client
  * @user_data: user data provided when connecting the signal
  *
- * Handler for #GDataMockServer::handle-message which sets the HTTP response for @message to the HTTP error status
+ * Handler for #UhmServer::handle-message which sets the HTTP response for @message to the HTTP error status
  * specified in a #GDataTestRequestErrorData structure passed to @user_data.
  *
  * Since: 0.13.4
  */
 gboolean
-gdata_test_mock_server_handle_message_error (GDataMockServer *server, SoupMessage *message, SoupClientContext *client, gpointer user_data)
+gdata_test_mock_server_handle_message_error (UhmServer *server, SoupMessage *message, SoupClientContext *client, gpointer user_data)
 {
 	const GDataTestRequestErrorData *data = user_data;
 
@@ -820,19 +989,19 @@ gdata_test_mock_server_handle_message_error (GDataMockServer *server, SoupMessag
 
 /**
  * gdata_test_mock_server_handle_message_timeout:
- * @server: a #GDataMockServer
+ * @server: a #UhmServer
  * @message: the message whose response should be filled
  * @client: the currently connected client
  * @user_data: user data provided when connecting the signal
  *
- * Handler for #GDataMockServer::handle-message which waits for 2 seconds before returning a %SOUP_STATUS_REQUEST_TIMEOUT status
+ * Handler for #UhmServer::handle-message which waits for 2 seconds before returning a %SOUP_STATUS_REQUEST_TIMEOUT status
  * and appropriate error message body. If used in conjunction with a 1 second timeout in the client code under test, this can
  * simulate network error conditions and timeouts, in order to test the error handling code for such conditions.
  *
  * Since: 0.13.4
  */
 gboolean
-gdata_test_mock_server_handle_message_timeout (GDataMockServer *server, SoupMessage *message, SoupClientContext *client, gpointer user_data)
+gdata_test_mock_server_handle_message_timeout (UhmServer *server, SoupMessage *message, SoupClientContext *client, gpointer user_data)
 {
 	/* Sleep for longer than the timeout set on the client. */
 	g_usleep (2 * G_USEC_PER_SEC);
