@@ -23,7 +23,7 @@
 #include "common.h"
 
 static GThread *main_thread = NULL;
-static GDataMockServer *mock_server = NULL;
+static UhmServer *mock_server = NULL;
 
 static void
 test_oauth1_authorizer_constructor (void)
@@ -80,8 +80,8 @@ typedef struct {
 
 	guint locale_notification_count;
 	gulong locale_signal_handler;
-	guint proxy_uri_notification_count;
-	gulong proxy_uri_signal_handler;
+	guint proxy_resolver_notification_count;
+	gulong proxy_resolver_signal_handler;
 	guint timeout_notification_count;
 	gulong timeout_signal_handler;
 } OAuth1AuthorizerData;
@@ -103,8 +103,8 @@ connect_to_oauth1_authorizer (OAuth1AuthorizerData *data)
 	/* Connect to notifications from the object to verify they're only emitted the correct number of times */
 	data->locale_signal_handler = g_signal_connect (data->authorizer, "notify::locale", (GCallback) notify_cb,
 	                                                &(data->locale_notification_count));
-	data->proxy_uri_signal_handler = g_signal_connect (data->authorizer, "notify::proxy-uri", (GCallback) notify_cb,
-	                                                   &(data->proxy_uri_notification_count));
+	data->proxy_resolver_signal_handler = g_signal_connect (data->authorizer, "notify::proxy-resolver", (GCallback) notify_cb,
+	                                                        &(data->proxy_resolver_notification_count));
 	data->timeout_signal_handler = g_signal_connect (data->authorizer, "notify::timeout", (GCallback) notify_cb,
 	                                                 &(data->timeout_notification_count));
 }
@@ -198,7 +198,7 @@ skip_test:
 	g_free (token_secret);
 	g_free (verifier);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 static void
@@ -206,7 +206,7 @@ tear_down_oauth1_authorizer_data (OAuth1AuthorizerData *data, gconstpointer user
 {
 	/* Clean up signal handlers */
 	g_signal_handler_disconnect (data->authorizer, data->timeout_signal_handler);
-	g_signal_handler_disconnect (data->authorizer, data->proxy_uri_signal_handler);
+	g_signal_handler_disconnect (data->authorizer, data->proxy_resolver_signal_handler);
 	g_signal_handler_disconnect (data->authorizer, data->locale_signal_handler);
 
 	g_object_unref (data->authorizer);
@@ -286,52 +286,52 @@ test_oauth1_authorizer_properties_locale (OAuth1AuthorizerData *data, gconstpoin
 	g_assert_cmpstr (gdata_oauth1_authorizer_get_locale (data->authorizer), ==, "de");
 }
 
-/* Test getting and setting the proxy-uri property */
+/* Test getting and setting the proxy-resolver property */
 static void
-test_oauth1_authorizer_properties_proxy_uri (OAuth1AuthorizerData *data, gconstpointer user_data)
+test_oauth1_authorizer_properties_proxy_resolver (OAuth1AuthorizerData *data, gconstpointer user_data)
 {
-	SoupURI *proxy_uri, *new_proxy_uri;
+	GProxyResolver *proxy_resolver, *new_proxy_resolver;
 
 	/* Verifying the normal state of the property in a newly-constructed instance of GDataOAuth1Authorizer */
-	g_assert (gdata_oauth1_authorizer_get_proxy_uri (data->authorizer) == NULL);
+	g_assert (gdata_oauth1_authorizer_get_proxy_resolver (data->authorizer) == NULL);
 
-	g_object_get (data->authorizer, "proxy-uri", &proxy_uri, NULL);
-	g_assert (proxy_uri == NULL);
+	g_object_get (data->authorizer, "proxy-resolver", &proxy_resolver, NULL);
+	g_assert (proxy_resolver == NULL);
 
-	g_assert_cmpuint (data->proxy_uri_notification_count, ==, 0);
+	g_assert_cmpuint (data->proxy_resolver_notification_count, ==, 0);
 
 	/* Check setting it works and emits a notification */
-	new_proxy_uri = soup_uri_new ("http://example.com/");
-	gdata_oauth1_authorizer_set_proxy_uri (data->authorizer, new_proxy_uri);
+	new_proxy_resolver = g_object_ref (g_proxy_resolver_get_default ());
+	gdata_oauth1_authorizer_set_proxy_resolver (data->authorizer, new_proxy_resolver);
 
-	g_assert_cmpuint (data->proxy_uri_notification_count, ==, 1);
+	g_assert_cmpuint (data->proxy_resolver_notification_count, ==, 1);
 
-	g_assert (gdata_oauth1_authorizer_get_proxy_uri (data->authorizer) != NULL);
-	g_assert (soup_uri_equal (gdata_oauth1_authorizer_get_proxy_uri (data->authorizer), new_proxy_uri) == TRUE);
+	g_assert (gdata_oauth1_authorizer_get_proxy_resolver (data->authorizer) != NULL);
+	g_assert (gdata_oauth1_authorizer_get_proxy_resolver (data->authorizer) == new_proxy_resolver);
 
-	g_object_get (data->authorizer, "proxy-uri", &proxy_uri, NULL);
-	g_assert (proxy_uri != NULL);
-	g_assert (soup_uri_equal (gdata_oauth1_authorizer_get_proxy_uri (data->authorizer), new_proxy_uri) == TRUE);
-	soup_uri_free (proxy_uri);
+	g_object_get (data->authorizer, "proxy-resolver", &proxy_resolver, NULL);
+	g_assert (proxy_resolver != NULL);
+	g_assert (gdata_oauth1_authorizer_get_proxy_resolver (data->authorizer) == new_proxy_resolver);
+	g_object_unref (proxy_resolver);
 
-	soup_uri_free (new_proxy_uri);
+	g_object_unref (new_proxy_resolver);
 
 	/* Check setting it back to NULL works */
-	gdata_oauth1_authorizer_set_proxy_uri (data->authorizer, NULL);
+	gdata_oauth1_authorizer_set_proxy_resolver (data->authorizer, NULL);
 
-	g_assert_cmpuint (data->proxy_uri_notification_count, ==, 2);
+	g_assert_cmpuint (data->proxy_resolver_notification_count, ==, 2);
 
-	g_assert (gdata_oauth1_authorizer_get_proxy_uri (data->authorizer) == NULL);
+	g_assert (gdata_oauth1_authorizer_get_proxy_resolver (data->authorizer) == NULL);
 
-	g_object_get (data->authorizer, "proxy-uri", &proxy_uri, NULL);
-	g_assert (proxy_uri == NULL);
+	g_object_get (data->authorizer, "proxy-resolver", &proxy_resolver, NULL);
+	g_assert (proxy_resolver == NULL);
 
 	/* Test that setting it using g_object_set() works */
-	new_proxy_uri = soup_uri_new ("http://example.com/");
-	g_object_set (data->authorizer, "proxy-uri", new_proxy_uri, NULL);
-	soup_uri_free (new_proxy_uri);
+	new_proxy_resolver = g_object_ref (g_proxy_resolver_get_default ());
+	g_object_set (data->authorizer, "proxy-resolver", new_proxy_resolver, NULL);
+	g_object_unref (new_proxy_resolver);
 
-	g_assert (gdata_oauth1_authorizer_get_proxy_uri (data->authorizer) != NULL);
+	g_assert (gdata_oauth1_authorizer_get_proxy_resolver (data->authorizer) != NULL);
 }
 
 /* Test getting and setting the timeout property */
@@ -395,7 +395,7 @@ test_oauth1_authorizer_refresh_authorization (OAuth1AuthorizerData *data, gconst
 	g_assert_no_error (error);
 	g_clear_error (&error);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 /* Test that processing a request with a NULL domain will not change the request. */
@@ -498,7 +498,7 @@ test_oauth1_authorizer_request_authentication_uri_sync (OAuth1AuthorizerData *da
 	g_assert_no_error (error);
 	g_assert (authentication_uri != NULL && *authentication_uri != '\0');
 	g_assert (token != NULL && *token != '\0');
-	g_assert (token_secret != NULL && *token_secret != '\0');
+	g_assert (token_secret != NULL && *token != '\0');
 	g_clear_error (&error);
 
 	g_test_message ("Requesting an authentication URI gave “%s” with request token “%s” and request token secret “%s”.",
@@ -508,7 +508,7 @@ test_oauth1_authorizer_request_authentication_uri_sync (OAuth1AuthorizerData *da
 	g_free (token);
 	g_free (token_secret);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 /* Test that requesting an authentication URI synchronously can be cancelled */
@@ -540,7 +540,7 @@ test_oauth1_authorizer_request_authentication_uri_sync_cancellation (OAuth1Autho
 
 	g_object_unref (cancellable);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 typedef struct {
@@ -588,7 +588,7 @@ test_oauth1_authorizer_request_authentication_uri_async_cb (GDataOAuth1Authorize
 	g_assert_no_error (error);
 	g_assert (authentication_uri != NULL && *authentication_uri != '\0');
 	g_assert (token != NULL && *token != '\0');
-	g_assert (token_secret != NULL && *token_secret != '\0');
+	g_assert (token_secret != NULL && *token != '\0');
 	g_clear_error (&error);
 
 	g_test_message ("Requesting an authentication URI asynchronously gave “%s” with request token “%s” and request token secret “%s”.",
@@ -614,7 +614,7 @@ test_oauth1_authorizer_request_authentication_uri_async (OAuth1AuthorizerAsyncDa
 
 	g_main_loop_run (data->main_loop);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 static void
@@ -661,7 +661,7 @@ test_oauth1_authorizer_request_authentication_uri_async_cancellation (OAuth1Auth
 
 	g_object_unref (cancellable);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 typedef struct {
@@ -692,7 +692,7 @@ set_up_oauth1_authorizer_interactive_data (OAuth1AuthorizerInteractiveData *data
 
 	g_free (authentication_uri);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 static void
@@ -715,7 +715,7 @@ set_up_oauth1_authorizer_interactive_data_bad_credentials (OAuth1AuthorizerInter
 
 	g_free (authentication_uri);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 static void
@@ -759,7 +759,7 @@ test_oauth1_authorizer_request_authorization_sync (OAuth1AuthorizerInteractiveDa
 	g_assert (gdata_authorizer_is_authorized_for_domain (GDATA_AUTHORIZER (data->parent.authorizer),
 	          gdata_contacts_service_get_primary_authorization_domain ()) == TRUE);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 /* Test that synchronously authorizing a request token fails if an invalid verifier is provided. */
@@ -786,7 +786,7 @@ test_oauth1_authorizer_request_authorization_sync_bad_credentials (OAuth1Authori
 	g_assert (gdata_authorizer_is_authorized_for_domain (GDATA_AUTHORIZER (data->parent.authorizer),
 	          gdata_contacts_service_get_primary_authorization_domain ()) == FALSE);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 /* Test that cancellation of synchronously authorizing a request token works. Note that this test has to be interactive, as the user has to visit the
@@ -826,7 +826,7 @@ test_oauth1_authorizer_request_authorization_sync_cancellation (OAuth1Authorizer
 
 	g_object_unref (cancellable);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 typedef struct {
@@ -906,7 +906,7 @@ test_oauth1_authorizer_request_authorization_async (OAuth1AuthorizerInteractiveA
 
 	g_main_loop_run (data->main_loop);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 static void
@@ -947,7 +947,7 @@ test_oauth1_authorizer_request_authorization_async_bad_credentials (OAuth1Author
 
 	g_main_loop_run (data->main_loop);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 static void
@@ -1001,25 +1001,25 @@ test_oauth1_authorizer_request_authorization_async_cancellation (OAuth1Authorize
 
 	g_object_unref (cancellable);
 
-	gdata_mock_server_end_trace (mock_server);
+	uhm_server_end_trace (mock_server);
 }
 
 static void
 mock_server_notify_resolver_cb (GObject *object, GParamSpec *pspec, gpointer user_data)
 {
-	GDataMockServer *server;
-	GDataMockResolver *resolver;
+	UhmServer *server;
+	UhmResolver *resolver;
 
-	server = GDATA_MOCK_SERVER (object);
+	server = UHM_SERVER (object);
 
 	/* Set up the expected domain names here. This should technically be split up between
 	 * the different unit test suites, but that's too much effort. */
-	resolver = gdata_mock_server_get_resolver (server);
+	resolver = uhm_server_get_resolver (server);
 
 	if (resolver != NULL) {
-		const gchar *ip_address = soup_address_get_physical (gdata_mock_server_get_address (server));
+		const gchar *ip_address = uhm_server_get_address (server);
 
-		gdata_mock_resolver_add_A (resolver, "www.google.com", ip_address);
+		uhm_resolver_add_A (resolver, "www.google.com", ip_address);
 	}
 }
 
@@ -1033,7 +1033,7 @@ main (int argc, char *argv[])
 	mock_server = gdata_test_get_mock_server ();
 	g_signal_connect (G_OBJECT (mock_server), "notify::resolver", (GCallback) mock_server_notify_resolver_cb, NULL);
 	trace_directory = g_file_new_for_path (TEST_FILE_DIR "traces/oauth1-authorizer");
-	gdata_mock_server_set_trace_directory (mock_server, trace_directory);
+	uhm_server_set_trace_directory (mock_server, trace_directory);
 	g_object_unref (trace_directory);
 
 	main_thread = g_thread_self ();
@@ -1048,8 +1048,8 @@ main (int argc, char *argv[])
 	            tear_down_oauth1_authorizer_data);
 	g_test_add ("/oauth1-authorizer/properties/locale", OAuth1AuthorizerData, NULL, set_up_oauth1_authorizer_data,
 	            test_oauth1_authorizer_properties_locale, tear_down_oauth1_authorizer_data);
-	g_test_add ("/oauth1-authorizer/properties/proxy-uri", OAuth1AuthorizerData, NULL, set_up_oauth1_authorizer_data,
-	            test_oauth1_authorizer_properties_proxy_uri, tear_down_oauth1_authorizer_data);
+	g_test_add ("/oauth1-authorizer/properties/proxy-resolver", OAuth1AuthorizerData, NULL, set_up_oauth1_authorizer_data,
+	            test_oauth1_authorizer_properties_proxy_resolver, tear_down_oauth1_authorizer_data);
 	g_test_add ("/oauth1-authorizer/properties/timeout", OAuth1AuthorizerData, NULL, set_up_oauth1_authorizer_data,
 	            test_oauth1_authorizer_properties_timeout, tear_down_oauth1_authorizer_data);
 
